@@ -49,6 +49,10 @@ def start_worker(config):
 
                 worker_life.job_id = None
 
+                if os.environ.get('RUNPOD_WEBHOOK_GET_JOB', None) is None:
+                    log("Local testing complete, exiting.")
+                    break
+
         if os.environ.get('RUNPOD_WEBHOOK_GET_JOB', None) is None:
             log("Local testing complete, exiting.")
             break
